#!/bin/bash

PWD_FILE=backupadmin.pwd
DEST_DIR=admin-backups
RSYNC_USER=backupadmin

# sleep for random amount of time to offset file accesses

if [[ "$1" == "--decongest" ]]; then
	sleep $[$RANDOM/10]
fi

# grab the backup settings from the user's backup-config dir

cd ~/.backup-config

mkdir -p backup-paths.d
rsync -q -a --delete --delete-after --password-file=${PWD_FILE} ${RSYNC_USER}@backups::${DEST_DIR}/${USERNAME}/backup-config/backup-paths.d .

# go through all the .path specification files

for pathfile in backup-paths.d/*.path; do

# copy the include and exclude specs to a safe filename
	echo -n >.includespec
	echo -n >.excludespec
	if [[ -s ${pathfile%.path}.include ]]; then
		cp "${pathfile%.path}.include" .includespec
	fi
	if [[ -s ${pathfile%.path}.exclude ]]; then
		cp "${pathfile%.path}.exclude" .excludespec
	fi

# convert the DOS path to cygwin

	rsync_path="$(< "${pathfile}")"
	rsync_path="$(cygpath -u "${rsync_path}")"

# perform the backup!
	echo -n "Backing up ${rsync_path} - "
	date

	rsync -q --recursive --times --delete --delete-after --password-file=${PWD_FILE} --include-from .includespec --exclude-from .excludespec "${rsync_path}" ${RSYNC_USER}@backups::${DEST_DIR}/${USERNAME}/auto-backups

done

